.. _zarr_docs_mainpage:

***********
Zarr-Python
***********

.. toctree::
    :maxdepth: 1
    :hidden:

    getting_started
    tutorial
    api
    spec
    release
    license
    acknowledgments
    contributing

**Version**: |version|

**Download documentation**: `PDF/Zipped HTML <https://readthedocs.org/projects/zarr/downloads/>`_

**Useful links**:
`Installation <installation.html>`_ |
`Source Repository <https://github.com/zarr-developers/zarr-python>`_ |
`Issue Tracker <https://github.com/zarr-developers/zarr-python/issues>`_ |
`Zulip Chat <https://ossci.zulipchat.com/>`_

Zarr is a file storage format for chunked, compressed, N-dimensional arrays based on an open-source specification.

.. grid:: 2

    .. grid-item-card::
        :img-top: _static/index_getting_started.svg

        Getting Started
        ^^^^^^^^^^^^^^^

        New to Zarr? Check out the getting started guide. It contains an
        introduction to Zarr's main concepts and links to additional tutorials.

        +++

        .. button-ref:: getting_started
            :expand:
            :color: dark
            :click-parent:

            To the getting started guide

    .. grid-item-card::
        :img-top: _static/index_user_guide.svg

        Tutorial
        ^^^^^^^^

        The tutorial provides working examples of Zarr classes and functions.

        +++

        .. button-ref:: tutorial
            :ref-type: ref
            :expand:
            :color: dark
            :click-parent:

            To the Tutorial

    .. grid-item-card::
        :img-top: _static/index_api.svg

        API Reference
        ^^^^^^^^^^^^^

        The reference guide contains a detailed description of the functions,
        modules, and objects included in Zarr. The reference describes how the
        methods work and which parameters can be used. It assumes that you have an
        understanding of the key concepts.

        +++

        .. button-ref:: api
            :expand:
            :color: dark
            :click-parent:

            To the api reference guide

    .. grid-item-card::
        :img-top: _static/index_contribute.svg

        Contributor's Guide
        ^^^^^^^^^^^^^^^^^^^

        Want to contribute to Zarr? We welcome contributions in the form of bug reports, bug fixes, documentation, enhancement proposals and more. The contributing guidelines will guide you through the process of improving Zarr.

        +++

        .. button-ref:: contributing
            :expand:
            :color: dark
            :click-parent:

            To the contributor's guide
